package OTRS::OPM::Installer::Types;
$OTRS::OPM::Installer::Types::VERSION = '0.03';
# ABSTRACT: Moo-Types for OTRS::OPM::Installer

use strict;
use warnings;

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

OTRS::OPM::Installer::Types - Moo-Types for OTRS::OPM::Installer

=head1 VERSION

version 0.03

=head1 AUTHOR

Renee Baecker <reneeb@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2017 by Renee Baecker.

This is free software, licensed under:

  The Artistic License 2.0 (GPL Compatible)

=cut
